==> rong-ui-react-0.0.3.tgz: package/es/modal/modal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import withPreventScroll from '../_hoc/withPreventScroll';
import withHashChange from '../_hoc/withHashChange';
import { CSSTransition } from 'react-transition-group';
var prefixCls = 'r-modal';

var Modal = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Modal, _React$PureComponent);

  var _super = _createSuper(Modal);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _super.call(this, props);

    _this.onEnter = function () {
      _this.resetPos();

      _this.props.withPreventScroll && _this.props.withPreventScroll.init({
        el: _this.modal.current
      });
    };

    _this.onExited = function () {
      _this.isMount = false;
      _this.props.fromInstance && ReactDOM.unmountComponentAtNode(_this.props.target);
    };

    _this.onCancel = function (e) {
      _this.props.onCancel && _this.props.onCancel.call(_assertThisInitialized(_this), e);
    };

    _this.onConfirm = function (e) {
      _this.props.onConfirm && _this.props.onConfirm.call(_assertThisInitialized(_this), e);
    };

    _this.onClose = function (e) {
      _this.props.onClose && _this.props.onClose.call(_assertThisInitialized(_this), e);
    };

    _this.remove = function () {
      _this.isMount && _this.setState({
        visible: false
      });
    };

    _this.state = {
      visible: props.visible,
      prevPropVisible: props.visible
    };
    _this.container = props.target;
    _this.modal = /*#__PURE__*/React.createRef();
    _this.modalWrap = /*#__PURE__*/React.createRef();
    return _this;
  }

  _createClass(Modal, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.isMount = true;
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.isMount = false;
    }
  }, {
    key: "resetPos",
    value: function resetPos() {
      var modalWrap = this.modalWrap.current;
      var dWidth = modalWrap.offsetWidth;
      var dHeight = modalWrap.offsetHeight;
      var wWidth = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;
      var wHeight = window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
      if (dWidth > wWidth) modalWrap.style.width = wWidth + 'px';
      if (dHeight > wHeight) modalWrap.style.height = wHeight + 'px';

      switch (this.props.position.x) {
        case 'left':
          modalWrap.style.left = '0px';
          break;

        case 'center':
          modalWrap.style.left = (wWidth - dWidth) / 2 + 'px';
          break;

        case 'right':
          modalWrap.style.right = '0px';
          break;

        default:
          modalWrap.style.left = this.props.position.x;
      }

      switch (this.props.position.y) {
        case 'top':
          modalWrap.style.top = '0px';
          break;

        case 'center':
          modalWrap.style.top = (wHeight - dHeight) / 2 + 'px';
          break;

        case 'bottom':
          modalWrap.style.bottom = '0px';
          break;

        default:
          modalWrap.style.top = this.props.position.y;
      }
    }
  }, {
    key: "wrapCls",
    get: function get() {
      var _ref;

      var _this$props = this.props,
          className = _this$props.className,
          showCancel = _this$props.showCancel,
          showConfirm = _this$props.showConfirm,
          showClose = _this$props.showClose,
          title = _this$props.title;
      return classNames([prefixCls, className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-cancel-btn-show"), showCancel), _defineProperty(_ref, "".concat(prefixCls, "-confirm-btn-show"), showConfirm), _defineProperty(_ref, "".concat(prefixCls, "-close-btn-show"), showClose), _defineProperty(_ref, "".concat(prefixCls, "-title-show"), !!title), _ref)]);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          title = _this$props2.title,
          titleStyle = _this$props2.titleStyle,
          showClose = _this$props2.showClose,
          closeStyle = _this$props2.closeStyle,
          content = _this$props2.content,
          children = _this$props2.children,
          contentStyle = _this$props2.contentStyle,
          showCancel = _this$props2.showCancel,
          cancelText = _this$props2.cancelText,
          cancelStyle = _this$props2.cancelStyle,
          showConfirm = _this$props2.showConfirm,
          confirmText = _this$props2.confirmText,
          confirmStyle = _this$props2.confirmStyle,
          cliperStyle = _this$props2.cliperStyle,
          dlgStyle = _this$props2.dlgStyle,
          fromInstance = _this$props2.fromInstance,
          cssTransitionClassName = _this$props2.cssTransitionClassName,
          cssTransitionTimeout = _this$props2.cssTransitionTimeout,
          unmountOnExit = _this$props2.unmountOnExit;
      var contentNode = /*#__PURE__*/React.createElement(CSSTransition, {
        in: this.state.visible,
        appear: true,
        classNames: cssTransitionClassName,
        timeout: cssTransitionTimeout,
        mountOnEnter: true,
        unmountOnExit: unmountOnExit,
        onEnter: this.onEnter,
        onExited: this.onExited
      }, /*#__PURE__*/React.createElement("div", {
        className: this.wrapCls,
        ref: this.modal,
        style: cliperStyle
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-wrap"),
        ref: this.modalWrap,
        style: dlgStyle
      }, title && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-title"),
        style: titleStyle
      }, title), showClose && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-close"),
        style: closeStyle,
        onClick: this.onClose
      }, /*#__PURE__*/React.createElement("svg", {
        width: "11px",
        height: "11px",
        viewBox: "0 0 11 11",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg",
        xmlnsXlink: "http://www.w3.org/1999/xlink"
      }, /*#__PURE__*/React.createElement("g", {
        stroke: "none",
        strokeWidth: "1",
        fill: "none",
        fillRule: "evenodd"
      }, /*#__PURE__*/React.createElement("g", {
        transform: "translate(-249.000000, -10.000000)",
        fill: "#999999"
      }, /*#__PURE__*/React.createElement("path", {
        d: "M254.50013,14.8683272 L249.762514,10.1306735 C249.588122,9.95644215 249.305423,9.95644215 249.130794,10.1306735 C248.956402,10.3052215 248.956402,10.5880359 249.130794,10.7624255 L253.868428,15.500023 L249.130795,20.2376113 C248.956402,20.4120016 248.956402,20.6948302 249.130795,20.8692073 C249.305425,21.0435976 249.588125,21.0435976 249.76228,20.8692073 L254.499971,16.1315614 L259.237665,20.8692176 C259.411819,21.0435941 259.694768,21.0435941 259.869384,20.8692176 C260.043539,20.694828 260.043539,20.4120004 259.869384,20.2376239 L255.131668,15.4998705 L259.869205,10.7623788 C260.043598,10.5880017 260.043598,10.3053314 259.869205,10.1307828 C259.694588,9.95640572 259.411875,9.95640572 259.23772,10.1307828 L254.50013,14.8683272 Z"
      }))))), (content || children) && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-content"),
        style: contentStyle
      }, content, " ", children), (showCancel || showConfirm) && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-btn")
      }, showCancel && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-cancel-btn"),
        style: cancelStyle,
        onClick: this.onCancel
      }, cancelText), showConfirm && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-confirm-btn"),
        style: confirmStyle,
        onClick: this.onConfirm
      }, confirmText)))));
      return this.container && !fromInstance ? /*#__PURE__*/ReactDOM.createPortal(contentNode, this.container) : contentNode;
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, preState) {
      if (nextProps.visible !== preState.prevPropVisible) {
        return {
          visible: nextProps.visible,
          prevPropVisible: nextProps.visible
        };
      }

      return null;
    }
  }]);

  return Modal;
}(React.PureComponent);

setDefaultProps(Modal, {
  // 标题
  title: {
    type: PropTypes.string
  },
  titleStyle: {
    type: PropTypes.object,
    default: {}
  },
  // closeBtn
  showClose: {
    type: PropTypes.bool,
    default: false
  },
  closeStyle: {
    type: PropTypes.object,
    default: {}
  },
  onClose: {
    type: PropTypes.func
  },
  // 内容
  content: {
    type: PropTypes.node,
    default: ''
  },
  contentStyle: {
    type: PropTypes.object
  },
  // cancelBtn
  cancelText: {
    type: PropTypes.node,
    default: '取消'
  },
  showCancel: {
    type: PropTypes.bool,
    default: true
  },
  cancelStyle: {
    type: PropTypes.object,
    default: {}
  },
  onCancel: {
    type: PropTypes.func
  },
  // confirmBtn
  confirmText: {
    type: PropTypes.node,
    default: '确定'
  },
  showConfirm: {
    type: PropTypes.bool,
    default: true
  },
  confirmStyle: {
    type: PropTypes.object,
    default: {}
  },
  onConfirm: {
    type: PropTypes.func
  },
  // 显示位置
  position: {
    type: PropTypes.object,
    default: {
      x: 'center',
      y: 'center'
    }
  },
  // hash变化时移除modal
  removeModalOnHashChange: {
    type: PropTypes.bool,
    default: true
  },
  // 自定义class
  className: {
    type: PropTypes.string,
    default: ''
  },
  // 可见
  visible: {
    type: PropTypes.bool,
    default: false
  },
  // cssTransition className
  cssTransitionClassName: {
    type: PropTypes.string,
    default: "".concat(prefixCls, "-fade")
  },
  // cssTransition timeout
  cssTransitionTimeout: {
    type: PropTypes.number,
    default: 300
  },
  // ummountOnExit 默认为false，表示当传入in的值为false值，CSSTransition中的元素不从dom中移除，传true时则会被移除
  unmountOnExit: {
    type: PropTypes.bool,
    default: false
  },
  // 遮罩层
  cliperStyle: {
    type: PropTypes.object
  },
  // modal框
  dlgStyle: {
    type: PropTypes.object
  }
});
Modal = withPreventScroll(Modal);
Modal = withHashChange(Modal);
export default Modal;

==> rong-ui-react-0.0.5.tgz: package/es/modal/modal.js <==
function _typeof(obj) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (obj) { return typeof obj; } : function (obj) { return obj && "function" == typeof Symbol && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }, _typeof(obj); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); Object.defineProperty(Constructor, "prototype", { writable: false }); return Constructor; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); Object.defineProperty(subClass, "prototype", { writable: false }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } else if (call !== void 0) { throw new TypeError("Derived constructors may only return object or undefined"); } return _assertThisInitialized(self); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Boolean.prototype.valueOf.call(Reflect.construct(Boolean, [], function () {})); return true; } catch (e) { return false; } }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

import React from 'react';
import ReactDOM from 'react-dom';
import PropTypes from 'prop-types';
import { setDefaultProps, classNames } from '../_util/assist';
import withPreventScroll from '../_hoc/withPreventScroll';
import withHashChange from '../_hoc/withHashChange';
import { CSSTransition } from 'react-transition-group';
var prefixCls = 'r-modal';

var Modal = /*#__PURE__*/function (_React$PureComponent) {
  _inherits(Modal, _React$PureComponent);

  var _super = _createSuper(Modal);

  function Modal(props) {
    var _this;

    _classCallCheck(this, Modal);

    _this = _super.call(this, props);

    _this.onEnter = function () {
      _this.resetPos();

      _this.props.withPreventScroll && _this.props.withPreventScroll.init({
        el: _this.modal.current
      });
    };

    _this.onExited = function () {
      _this.isMount = false;

      if (_this.props.fromInstance) {
        ReactDOM.unmountComponentAtNode(_this.props.target);
        document.body.removeChild(_this.props.target);
      }
    };

    _this.onCancel = function (e) {
      _this.props.onCancel && _this.props.onCancel.call(_assertThisInitialized(_this), e);
    };

    _this.onConfirm = function (e) {
      _this.props.onConfirm && _this.props.onConfirm.call(_assertThisInitialized(_this), e);
    };

    _this.onClose = function (e) {
      _this.props.onClose && _this.props.onClose.call(_assertThisInitialized(_this), e);
    };

    _this.remove = function () {
      _this.isMount && _this.setState({
        visible: false
      });
    };

    _this.state = {
      visible: props.visible,
      prevPropVisible: props.visible
    };
    _this.container = props.target;
    _this.modal = /*#__PURE__*/React.createRef();
    _this.modalWrap = /*#__PURE__*/React.createRef();
    return _this;
  }

  _createClass(Modal, [{
    key: "componentDidMount",
    value: function componentDidMount() {
      this.isMount = true;
    }
  }, {
    key: "componentWillUnmount",
    value: function componentWillUnmount() {
      this.isMount = false;
    }
  }, {
    key: "resetPos",
    value: function resetPos() {
      var modalWrap = this.modalWrap.current;
      var dWidth = modalWrap.offsetWidth;
      var dHeight = modalWrap.offsetHeight;
      var wWidth = window.innerWidth || document.documentElement.clientWidth || document.body.clientWidth;
      var wHeight = window.innerHeight || document.documentElement.clientHeight || document.body.clientHeight;
      if (dWidth > wWidth) modalWrap.style.width = wWidth + 'px';
      if (dHeight > wHeight) modalWrap.style.height = wHeight + 'px';

      switch (this.props.position.x) {
        case 'left':
          modalWrap.style.left = '0px';
          break;

        case 'center':
          modalWrap.style.left = (wWidth - dWidth) / 2 + 'px';
          break;

        case 'right':
          modalWrap.style.right = '0px';
          break;

        default:
          modalWrap.style.left = this.props.position.x;
      }

      switch (this.props.position.y) {
        case 'top':
          modalWrap.style.top = '0px';
          break;

        case 'center':
          modalWrap.style.top = (wHeight - dHeight) / 2 + 'px';
          break;

        case 'bottom':
          modalWrap.style.bottom = '0px';
          break;

        default:
          modalWrap.style.top = this.props.position.y;
      }
    }
  }, {
    key: "wrapCls",
    get: function get() {
      var _ref;

      var _this$props = this.props,
          className = _this$props.className,
          showCancel = _this$props.showCancel,
          showConfirm = _this$props.showConfirm,
          showClose = _this$props.showClose,
          title = _this$props.title;
      return classNames([prefixCls, className, (_ref = {}, _defineProperty(_ref, "".concat(prefixCls, "-cancel-btn-show"), showCancel), _defineProperty(_ref, "".concat(prefixCls, "-confirm-btn-show"), showConfirm), _defineProperty(_ref, "".concat(prefixCls, "-close-btn-show"), showClose), _defineProperty(_ref, "".concat(prefixCls, "-title-show"), !!title), _ref)]);
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          title = _this$props2.title,
          titleStyle = _this$props2.titleStyle,
          showClose = _this$props2.showClose,
          closeStyle = _this$props2.closeStyle,
          content = _this$props2.content,
          children = _this$props2.children,
          contentStyle = _this$props2.contentStyle,
          showCancel = _this$props2.showCancel,
          cancelText = _this$props2.cancelText,
          cancelStyle = _this$props2.cancelStyle,
          showConfirm = _this$props2.showConfirm,
          confirmText = _this$props2.confirmText,
          confirmStyle = _this$props2.confirmStyle,
          cliperStyle = _this$props2.cliperStyle,
          dlgStyle = _this$props2.dlgStyle,
          fromInstance = _this$props2.fromInstance,
          cssTransitionClassName = _this$props2.cssTransitionClassName,
          cssTransitionTimeout = _this$props2.cssTransitionTimeout,
          unmountOnExit = _this$props2.unmountOnExit;
      var contentNode = /*#__PURE__*/React.createElement(CSSTransition, {
        in: this.state.visible,
        appear: true,
        classNames: cssTransitionClassName,
        timeout: cssTransitionTimeout,
        mountOnEnter: true,
        unmountOnExit: unmountOnExit,
        onEnter: this.onEnter,
        onExited: this.onExited
      }, /*#__PURE__*/React.createElement("div", {
        className: this.wrapCls,
        ref: this.modal,
        style: cliperStyle
      }, /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-wrap"),
        ref: this.modalWrap,
        style: dlgStyle
      }, title && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-title"),
        style: titleStyle
      }, title), showClose && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-close"),
        style: closeStyle,
        onClick: this.onClose
      }, /*#__PURE__*/React.createElement("svg", {
        width: "11px",
        height: "11px",
        viewBox: "0 0 11 11",
        version: "1.1",
        xmlns: "http://www.w3.org/2000/svg",
        xmlnsXlink: "http://www.w3.org/1999/xlink"
      }, /*#__PURE__*/React.createElement("g", {
        stroke: "none",
        strokeWidth: "1",
        fill: "none",
        fillRule: "evenodd"
      }, /*#__PURE__*/React.createElement("g", {
        transform: "translate(-249.000000, -10.000000)",
        fill: "#999999"
      }, /*#__PURE__*/React.createElement("path", {
        d: "M254.50013,14.8683272 L249.762514,10.1306735 C249.588122,9.95644215 249.305423,9.95644215 249.130794,10.1306735 C248.956402,10.3052215 248.956402,10.5880359 249.130794,10.7624255 L253.868428,15.500023 L249.130795,20.2376113 C248.956402,20.4120016 248.956402,20.6948302 249.130795,20.8692073 C249.305425,21.0435976 249.588125,21.0435976 249.76228,20.8692073 L254.499971,16.1315614 L259.237665,20.8692176 C259.411819,21.0435941 259.694768,21.0435941 259.869384,20.8692176 C260.043539,20.694828 260.043539,20.4120004 259.869384,20.2376239 L255.131668,15.4998705 L259.869205,10.7623788 C260.043598,10.5880017 260.043598,10.3053314 259.869205,10.1307828 C259.694588,9.95640572 259.411875,9.95640572 259.23772,10.1307828 L254.50013,14.8683272 Z"
      }))))), (content || children) && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-content"),
        style: contentStyle
      }, content, " ", children), (showCancel || showConfirm) && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-btn")
      }, showCancel && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-cancel-btn"),
        style: cancelStyle,
        onClick: this.onCancel
      }, cancelText), showConfirm && /*#__PURE__*/React.createElement("div", {
        className: "".concat(prefixCls, "-confirm-btn"),
        style: confirmStyle,
        onClick: this.onConfirm
      }, confirmText)))));
      return this.container && !fromInstance ? /*#__PURE__*/ReactDOM.createPortal(contentNode, this.container) : contentNode;
    }
  }], [{
    key: "getDerivedStateFromProps",
    value: function getDerivedStateFromProps(nextProps, preState) {
      if (nextProps.visible !== preState.prevPropVisible) {
        return {
          visible: nextProps.visible,
          prevPropVisible: nextProps.visible
        };
      }

      return null;
    }
  }]);

  return Modal;
}(React.PureComponent);

setDefaultProps(Modal, {
  // 标题
  title: {
    type: PropTypes.string
  },
  titleStyle: {
    type: PropTypes.object,
    default: {}
  },
  // closeBtn
  showClose: {
    type: PropTypes.bool,
    default: false
  },
  closeStyle: {
    type: PropTypes.object,
    default: {}
  },
  onClose: {
    type: PropTypes.func
  },
  // 内容
  content: {
    type: PropTypes.node,
    default: ''
  },
  contentStyle: {
    type: PropTypes.object
  },
  // cancelBtn
  cancelText: {
    type: PropTypes.node,
    default: '取消'
  },
  showCancel: {
    type: PropTypes.bool,
    default: true
  },
  cancelStyle: {
    type: PropTypes.object,
    default: {}
  },
  onCancel: {
    type: PropTypes.func
  },
  // confirmBtn
  confirmText: {
    type: PropTypes.node,
    default: '确定'
  },
  showConfirm: {
    type: PropTypes.bool,
    default: true
  },
  confirmStyle: {
    type: PropTypes.object,
    default: {}
  },
  onConfirm: {
    type: PropTypes.func
  },
  // 显示位置
  position: {
    type: PropTypes.object,
    default: {
      x: 'center',
      y: 'center'
    }
  },
  // hash变化时移除modal
  removeModalOnHashChange: {
    type: PropTypes.bool,
    default: true
  },
  // 自定义class
  className: {
    type: PropTypes.string,
    default: ''
  },
  // 可见
  visible: {
    type: PropTypes.bool,
    default: false
  },
  // cssTransition className
  cssTransitionClassName: {
    type: PropTypes.string,
    default: "".concat(prefixCls, "-fade")
  },
  // cssTransition timeout
  cssTransitionTimeout: {
    type: PropTypes.number,
    default: 300
  },
  // ummountOnExit 默认为false，表示当传入in的值为false值，CSSTransition中的元素不从dom中移除，传true时则会被移除
  unmountOnExit: {
    type: PropTypes.bool,
    default: false
  },
  // 遮罩层
  cliperStyle: {
    type: PropTypes.object
  },
  // modal框
  dlgStyle: {
    type: PropTypes.object
  }
});
Modal = withPreventScroll(Modal);
Modal = withHashChange(Modal);
export default Modal;
